extensions [matrix]

breed[investors investor]
breed[entrepreneurs entrepreneur]

undirected-link-breed [entrepreneur-links entrepreneur-link] ;links between investors and entrepreneurs
undirected-link-breed [investor-links investor-link] ; links between investors


globals
[
;number-investors
;number-entrepreneurs
;productivity
;trust-cutoff             ;when trust falls below this threshold, the link is cut
;disappointment-threshold ;when the return an investor receives is lower than this times the other investors' average return, he is disappointed and trust decreases
;memory                   ;length of memory
;mean-stochastic           ;parameters of stochastic component of returns
;variance-stochastic
;time-constraint-investors         ;maximum time (time costs) investors can spend on their links to other investors
;time-constraint-entrepreneurs               ;maximum time (time costs) investors can spend on their links to entrepreneurs
;adaption: adaption of p1, p2 and p3 by entrepreneurs
returnbigger0 ; measures how many entrepreneurs have return bigger 0
budget-counter ;auxiliary variable needed for link formation

comparisonlist-global; auxiliary list for updating trust

;minimum-p3 ;minimum savings into private wealth each period (if the entrepreneur can afford it)
link-being-cut ;global count variable: how many links are being cut this period?
; saving-target
;adaptation-speed
dead-investors ;counts the number of investors that have exited the market
link-age-at-death ; list collecting the average age at which links are cut
return-received-bigger ;in how many cases is return-received bigger than amount-invested? List
return-received-total; measures total return received across all investors and all periods
dead-links ; measures total number of cut links across all periods
no-loss ; proportion of investments that were not a loss to the investor
investor-profit-list; list of investors' profit across all periods
return-measure ; measure to compare model return with empirical return
duration-investment ; average duration of investment
]


investors-own
[
  culture
  capital
 
  connectionslist ; list of entrepreneurs the investor has ever been connected with
  
  difference-absolute ; sum of absolute values of differences of both culture values
  time-budget-investors
  time-budget-entrepreneurs
  should-die ; investor dies next period
  capital-1 ;-1 indicates previous period
  capital-2 ; -2 indicates two periods ago
  inactivity1 ;first period of inactivity 
  inactivity2 ;last period
  inactivity3 ;periods in between
  invested-amount ; amount invested by an investor in a period
  
  investor-age
]


entrepreneurs-own
[
culture
capital
private-wealth
difference-absolute ; distance between turtles (= difference in culture values)
return ; from production

investment-received ;amount of investment invested with the entrepreneur this period
p1 ;amount (part of profit) returned to investor as interest payment
p2  ;amount (part of profit) to invest himself
p3 ; amount (part of profit) to put in private wealth

age
return-1
profit-1
return-2
profit-2
p1-1
p2-1
p1-2
p2-2
profit
should-die ;1 if the entrepreneur dies at the beginning of the next tick
voluntary ; 1 if the entrepreneur exits the market voluntarily
error-term-environment ;idiosyncratic
inactivity1
inactivity2
inactivity3
]


entrepreneur-links-own
[
trust
disappointed ; 1 if investor is disappointed with the connected entrepreneur
amount-invested ;amount invested with the link in a period
amount-invested-list ; list needed to compute the proportion of investments that investors lose money on
return-received-now ; return received by the investor from the entrepreneur this period
return-received-1
return-received-2
return-received ; list with the returns received by the investor each period
rate-of-return-perinvestment ; total rate of return in a relationship between investor and entrepreneur across several periods
new-link; is the link a new link? 
comparison-list ; auxiliary list for investors to decide
already-checked1 ;for update trust procedure
already-checked2 ;for update trust procedure
being-checked ;for update trust procedure
should-die-link ; link will die next period
age-link
]


to setup
ca

;create investors
ask n-of number-investors patches 
               [sprout-investors 1
               ]  
;give attributes to investors
ask investors [
               set capital 1000
               set shape "dollar bill"
               set color blue
               set culture list (xcor / 10) (ycor / 10)
               set connectionslist []
               set time-budget-investors time-constraint-investors
               set time-budget-entrepreneurs time-constraint-entrepreneurs
               
               set investor-age 0
              ]
;investors create links to other investors. This happens only in setup.
ask investors [links-to-others]
;create entrepreneurs
ask n-of number-entrepreneurs patches 
               [sprout-entrepreneurs 1
               ]
;give attributes to entrepreneurs
ask entrepreneurs [
                   set shape "computer workstation"
                   set color orange
                   
                   set capital 0
                   set private-wealth 0
                   set difference-absolute 0; Euclidian distance between turtles (= difference in culture values)
                   set return 0

                   set investment-received 0 ;amount of investment invested with the entrepreneur this period
                   set p1 0;amount (part of profit) returned to investor
                   set p2 0 ;amount (part of profit) to invest himself
                   set p3 minimum-p3; amount (part of profit) to put in private wealth (if the entrepreneur can afford it)

                   set age 0 
                   set return-1 0
                   set profit-1 0
                   set return-2 0
                   set profit-2 0
                   set p1-1 0
                   set p2-1 0
                   set p1-2 0
                   set p2-2 0
                   set profit 0
                   set should-die 0;1 if the entrepreneur dies at the beginning of the next tick
                   set voluntary 0
                   set error-term-environment random-normal mean-stochastic variance-stochastic ;idiosyncratic
                   set inactivity1 0
                   set inactivity2 0
                   set inactivity3 0
                   set culture list (xcor / 10) (ycor / 10)
                   set p3 minimum-p3
                   
                  ]


set comparisonlist-global []
set link-age-at-death []
set return-received-bigger []
set return-received-total []
set dead-links 0
set investor-profit-list []
set return-measure 10000
set duration-investment 0
end


to go

tick
update
ask entrepreneurs [get-older]
ask investors [create-links]
ask investors [investment-decision]
ask investors [invest]
ask entrepreneurs [compute-return]
ask entrepreneurs [optimization-entrepreneurs] ; this is not really an optimization; it is still called "optimization" because of a previous model version
ask entrepreneurs [inform-investors]
set returnbigger0 count entrepreneurs with [age > 2 and return > 0.1] ;measure entrepreneurs with positive return
ask entrepreneur-links [ifelse sum amount-invested-list > 0 ;measure to compute overall rate of return of an investment
                         [set rate-of-return-perinvestment (sum return-received / sum amount-invested-list ) ^ ( 1 / age-link) - 1  ]
                         [set rate-of-return-perinvestment 0]
                        ]

ask investors [update-trust]
ask investors [cut-link]

ask entrepreneurs [exit]
ask investors [exit-investors]
do-plots


end

to links-to-others
ask other investors [set color pink ;every investor sets all the other investors pink so that he knows they are not him
                    
                     set difference-absolute distance myself ;the difference-absolute value of each investor is set to the distance of the calling investor 
                     ]
while [time-budget-investors >= 0 and  budget-counter = 0] ;while the investor still has time-budget left
      [
       let newcontact one-of other investors with [color = pink] with-min [difference-absolute] ;check the closest investor that is pink
       ifelse [difference-absolute] of newcontact <= time-budget-investors ; if distance is not so big that when adding that distance to the budget it would excede the time-contraint
                [ ask newcontact [set color red]
                 
                 create-investor-link-with newcontact
                 set time-budget-investors time-budget-investors - [difference-absolute] of newcontact ;subtract the budget used up for this investor contact from the total time budget 
                 ask newcontact [set color green] 
                ]
                [set budget-counter 1 ;exit the while procedure if that person's distance is too large
                ]
      ]

set budget-counter 0
ask investors [set color blue ;back to normal
               
               set difference-absolute 0 ;is going to be set to a different value when the next investor asks
              ]
ask investor-links [set color blue]
end



to update 


set dead-links dead-links + count entrepreneur-links with [should-die-link = 1] ;measures all links that are going to die now (because of something that happened last period)

ifelse any? entrepreneur-links with [should-die-link = 1]
       [set return-received-bigger fput count entrepreneur-links with [sum return-received > sum amount-invested-list and should-die-link = 1] return-received-bigger ;those links are added to a list if the amount returned through them was large than the amount invested 
        set return-measure abs((mean [rate-of-return-perinvestment] of entrepreneur-links with [should-die-link = 1] ) - 0.31) ;measure to compare return to empirical value
        ]
       [ifelse any? entrepreneur-links
         [set return-measure abs((mean [rate-of-return-perinvestment] of entrepreneur-links  ) - 0.31) ;if no entrepreneur-links with should-die-link = 1: take all links
         ]
         [; don't change return measure. If there have never been any links, return-measure is 10000 (the setup value) 
         ]
        ]

ifelse dead-links > 0
  [set no-loss (sum return-received-bigger ) / dead-links ] ;with which proportion of investments did the investors not make a loss?
  [set no-loss 0]


if any? entrepreneur-links with [should-die-link = 1]
    [set link-age-at-death fput (mean [age-link] of entrepreneur-links with [should-die-link = 1]) link-age-at-death ;to compute the duration of investments
     set duration-investment mean [age-link] of entrepreneur-links with [should-die-link = 1]
     ]

ask entrepreneur-links 
[if should-die-link = 1 
  [set return-received-total fput sum return-received return-received-total ;set return from this link to the list collecting the total returns from this market 
    die] ;then die if supposed to die
 set new-link 0  ;all currently existing links are not new anymore
 set age-link age-link + 1 ;links age
 set amount-invested 0 ;set back to 0 for the next round
 set return-received-2 return-received-1
 set return-received-1 return-received-now
 set return-received-now 0
 
 set disappointed 0
 
]





ask entrepreneurs 
[ if should-die = 1 
   [                
     hatch 1 ;new entrepreneur is created; initial location is the same as its parent; so it still has to move
       [           setxy random-xcor random-ycor
                   set shape "computer workstation"
                   set color orange
                   
                   set capital 0
                   set private-wealth 0
                   set difference-absolute 0; distance between turtles (= difference in culture values)
                   set return 0

                   set investment-received 0 ;amount of investment invested with the entrepreneur this period
                   set p1 0;amount (part of profit) returned to investor
                   set p2 0 ;amount (part of profit) to invest himself
                   set p3 minimum-p3; amount (part of profit) to put in private wealth

                   set age 0
                   set return-1 0
                   set profit-1 0
                   set return-2 0
                   set profit-2 0
                   set p1-1 0
                   set p2-1 0
                   set p1-2 0
                   set p2-2 0
                   set profit 0
                   set should-die 0;1 if the entrepreneur dies at the beginning of the next tick
                   set voluntary 0
                   set error-term-environment random-normal mean-stochastic variance-stochastic ;idiosyncratic
                   set inactivity1 0
                   set inactivity2 0
                   set inactivity3 0
                   set culture list (xcor / 10) (ycor / 10)
                   set p3 minimum-p3
       ]
     die ;the old entrepreneur dies after he has created a new one
    ]
 set error-term-environment random-normal mean-stochastic variance-stochastic ;all entrepreneurs receive a new random value for the environmental impact on their returns

 if capital = 0 and profit = 0 and investment-received = 0 and age > 1 ;if an entrepreneur does not receive investment and does not have any capital to put in the firm himself he is inactive
           [ifelse inactivity1 = 0 ;not inactive before
             [set inactivity1 ticks  ;set the current moment as the beginning of inactivity
             ]
             [set inactivity2 ticks ;if this was the last period of inactivity
              set inactivity3 inactivity3 + 1 ;prolong the duration of inactivity by 1
             ]
           ]          

if ticks > inactivity2 and inactivity1 > 0 and inactivity2 > 0 ; inactivity not in consecutive periods
 [set inactivity1 0
  set inactivity2 0
  set inactivity3 0
  ;start counting from scratch
 ]
  
 set investment-received 0
 set return-2 return-1
 set return-1 return
 set return 0
 
 set profit-2 profit-1
 set profit-1 profit
 set profit 0 
 
 set p1-2 p1-1
 set p1-1 p1
 set p1 0
 
 set p2-2 p2-1
 set p2-1 p2
 set p2 0



]

ask investors
[if should-die = 1 ;when investor dies, he also creates a replacement
  [hatch 1
      [setxy random-xcor random-ycor
       set capital 1000
       set shape "dollar bill"
       set color blue
       set culture list (xcor / 10) (ycor / 10)
       set connectionslist []
       set time-budget-investors time-constraint-investors
       set time-budget-entrepreneurs time-constraint-entrepreneurs 
       set investor-age 0
       links-to-others
       ]
    die];old investor dies
 set capital-2 capital-1
 set capital-1 capital
 set investor-age investor-age + 1 ;investor ages
 if capital = 0 or [amount-invested] of my-entrepreneur-links = 0 ;investor is inactive if he has not invested or has no captial left
           [ifelse inactivity1 = 0 
             [set inactivity1 ticks  
             ]
             [set inactivity2 ticks
              set inactivity3 inactivity3 + 1
             ]
           ]          
if ticks != inactivity2 and inactivity1 > 0 and inactivity2 > 0; inactivity not in consecutive periods
 [set inactivity1 0
  set inactivity2 0
  set inactivity3 0
  ;start counting from scratch
 ]


]




set link-being-cut 0



end



to get-older
set age age + 1
end

to create-links ;investors create links to entrepreneur. This works in principle the same way as creating links to other investors above, with a few more checks.
ask entrepreneurs with [not link-neighbor?  myself ] [set color pink  ;everyone that I am not yet currently connected to is selected
                                                                     
                                                      set difference-absolute distance myself ;those entrepreneurs calculate their difference to the calling investor
                                                      ] 

                       
while [any? entrepreneurs with [color = pink] and time-budget-entrepreneurs > 0 and budget-counter = 0]
      [ let kandidaten entrepreneurs with [color = pink] ;everyone that is still pink
        let newcontact one-of kandidaten with-min [difference-absolute] ;of those, the ones that are closest
 
       ask newcontact [set color red] ;the ones that are being checked are colored red
        ifelse member? newcontact connectionslist ;if previously connected but disappointed by that entrepreneur
        [; don't do anything. But entrepreneur is coloured in red anyway, so he cannot be chosen again
        ]
       
         [ifelse [difference-absolute] of newcontact <= time-budget-entrepreneurs ; if distance is not so big that when adding that distance to the budget it would excede the time-contraint
             [create-entrepreneur-link-with newcontact
              set time-budget-entrepreneurs time-budget-entrepreneurs - [difference-absolute] of newcontact ;time-budget of the investor is updated
              let newlink entrepreneur-link-with newcontact
              ask newcontact [set color green] 
              ask newlink [set trust (1 / ([difference-absolute] of newcontact + 0.1))  ;dont divide by 0, therefore +0.1 
                           set disappointed 0
                           set amount-invested 0
                           set return-received []
                           set amount-invested-list []
                           set comparison-list []
                           set new-link 1
                           set color orange
                           set age-link 1
                           set rate-of-return-perinvestment 0
                          
                           ]
              set connectionslist fput newcontact connectionslist ;the new connected entrepreneur is added to the list of current and past connections of the investor
              ]
              [set budget-counter 1 ;when the time-budget is exhausted, get oout of the while loop
              ]
         ]
      ]
set budget-counter 0  
ask entrepreneurs [set color orange
                  
                   set difference-absolute 0
                  ]
     
end


to investment-decision ;investors decide how much to invest with which of their connected entrepreneurs 
decide-amount
decide-distribution

end


to decide-amount

ifelse capital <= 0
[set invested-amount 0
]
[set invested-amount investment  ;in this version: the same for everyone. Could easily be endogenized or idiosyncratic
]



end




to decide-distribution

ifelse any? my-entrepreneur-links  
   [ let total-returns sum [sum return-received] of my-entrepreneur-links
     ifelse total-returns = 0   ;so far no return from anyone
           [let numberoflinks count my-entrepreneur-links  
             ask my-entrepreneur-links [set amount-invested [invested-amount] of myself  * (1 / numberoflinks) ;if this is the first round or I have not yet received anything: every entrepreneur gets the same amount
                                        set amount-invested-list fput amount-invested amount-invested-list ; add the newly invested amount to the list that collects all the investment along this link / in this relationship
                                        ] 
           ] ;if I have received returns previously
           [ifelse any? my-entrepreneur-links with [new-link = 1] ; if I have any new links
               [let numberoflinks count my-entrepreneur-links
                let countnewlinks count my-entrepreneur-links with [new-link = 1]
                ask my-entrepreneur-links with [new-link = 1]
                     [set amount-invested [invested-amount] of myself  * (1 / numberoflinks) ; the new link receives the amount he would get if I just gave all my links the same amount
                      set amount-invested-list fput amount-invested amount-invested-list ; add that amount to the list of investments
                     ]
                ask my-entrepreneur-links with [new-link = 0];the rest is distributed among the "old" links
                        [set amount-invested ([invested-amount] of myself - (([invested-amount] of myself / numberoflinks) * countnewlinks)) * ((sum return-received) / total-returns) ;first subtract what was given to the new links. Then, of the rest, those that have given more to the investor in the past receive proportionally more
                         set amount-invested-list fput amount-invested amount-invested-list  
                         ] 
               
               ]
               [ask my-entrepreneur-links ; if I do not have any new links 
                   [set amount-invested [invested-amount] of myself  * ((sum return-received) / total-returns ) ; all links just receive the proportion of the investor's investment that corresponds to that link's contribution to the investor's returns
                    set amount-invested-list fput amount-invested amount-invested-list
                    ]            
                    
               ]
             
           ]    
   ]
   [; if I don't have any links: don't invest
     
   ] 


end





to invest
ifelse any? entrepreneur-links 
  [ask my-entrepreneur-links 
       [ask other-end [set investment-received investment-received + [amount-invested] of myself] ;the entrepreneurs are asked by the links to add the amount of investment that flows through the link to their total investment
        
       ]
   set capital capital - sum [amount-invested] of my-entrepreneur-links ;the amount that is invested by the investor is subtracted from his capital
  ]
  [; don't invest
  ]

end

to compute-return ;entrepreneurs comute their return
set return (productivity + error-term-environment) * (capital + investment-received) ;production function 
set capital 0 ; the entrepreneurs capital (what he himself has saved for investing in the firm) is set to 0 because it has just been invested in the production process
set profit return - investment-received ;profit is what remains after paying back the investment received

end


to optimization-entrepreneurs
optimize
end 



to optimize ;as mentioned previously, this is not really an optimization, it is just called that because of an earlier version
ifelse profit >= 0
  [ifelse age = 1 ;if I have no experience in what to do with my profits
    [ifelse profit >= minimum-p3 
       [set p3 minimum-p3 ;if I have at least the minimum value to be added to private wealth, I do that
        set private-wealth private-wealth + minimum-p3
        set p1 (profit - minimum-p3) * 0.5 ;split profit equally between what I return to the investor and what I invest myself in the firm next period
        set p2 (profit - minimum-p3) * 0.5
       ]
       [set p3 profit ;if my profit is smaller than the minimum to set aside for private wealth
        set private-wealth private-wealth + profit ;use all that little profit as a buffer and put into private wealth
        set p1 0
        set p2 0 
       ]
    ]
    [ifelse profit >= profit-1  ;if this is not my first time and profit has increased
      [ifelse p1-1 >= p1-2 ;the amount given back to investors has increased leading up to this production period
           [; increase p1 further if possible because it seems to help
             ifelse profit >= p1-1 + adaptation-speed + minimum-p3 ;if I can increase p1 by the full amount I would like to increase it (adaptation speed), do that
                 [ set p3 minimum-p3
                   set private-wealth private-wealth + minimum-p3
                   set p1 p1-1 + adaptation-speed 
                   ifelse profit - p1 - p3 >= p2-1 ; if possible, p2 is set as high as it was before 
                      [set p2 p2-1
                      ; remaining profit is split equally between p1 and p2
                       let nochdazu profit - p1 - p2 - p3
                       set p1 p1 + 0.5 * nochdazu
                       set p2 p2 + 0.5 * nochdazu
                      ]
                      [; if p2-1 cannot be reached anymore, set p2 as large as possible 
                        set p2 profit - p1 - p3
                      ]
                 ]                 
                 [; can profit at least cover the old p1 + minimum addition to private wealth?
                   ifelse profit >= p1-1 + minimum-p3
                       [set p3 minimum-p3
                        set private-wealth private-wealth + minimum-p3
                        set p1 profit - minimum-p3 ;p1 as large as possible, if it is not possible to set p1 equal to p1-1 + adaptation-speed 
                        set p2 0 ;nothing left for p2
                       ]
                       [; can profit at least cover the minimum addition to private wealth?
                        ifelse profit >= minimum-p3
                            [set p3 minimum-p3
                             set private-wealth private-wealth + minimum-p3
                             set p1 profit - minimum-p3 ; p1 as high as possible, if I can't afford p1-1 
                             set p2 0 ; nothing left for p2 
                            ]
                            [; if I can't even cover minimum-p3
                             set p3 profit ;p3 as large as pssible
                             set private-wealth private-wealth + profit
                             set p1 0
                             set p2 0
                            ] 
                       ]
                 ]  
           
           ]
           [; if p1-1 < p1-2, but the profit was still higher: I got the higher profit because I gave less to the investors. Therefore: lower the amount further
            ;increase p2 further if prossible because it seems to help
            ifelse profit >= p2-1 + adaptation-speed + minimum-p3
                 [ set p3 minimum-p3
                   set private-wealth private-wealth + minimum-p3
                   set p2 p2-1 + adaptation-speed
                   ifelse profit - p2 - p3 >= p1-1 ; p1 as high as it was before, if possible
                      [set p1 p1-1
                      ; remaining profit is distributed equally among p1 and p2
                       let nochdazu profit - p1 - p2 - p3
                       set p1 p1 + 0.5 * nochdazu
                       set p2 p2 + 0.5 * nochdazu
                      ]
                      [; if I can't reach p1-1 anymore it is at least set as high as possible
                        set p1 profit - p2 - p3
                      ]

                 ]                 
                 [; can profit at least cover the old p2 + minimum addition to private wealth?
                   ifelse profit >= p2-1 + minimum-p3
                       [set p3 minimum-p3
                        set private-wealth private-wealth + minimum-p3
                        set p2 profit - minimum-p3 ;p2 as large as possible, if I cannot reach p2-1 + adaptation-speed 
                        set p1 0 ;nothing left for p1
                       ]
                       [; can profit at least cover the minimum addition to private wealth?
                        ifelse profit >= minimum-p3
                            [set p3 minimum-p3
                             set private-wealth private-wealth + minimum-p3
                             set p2 profit - minimum-p3 ; p1 as high as possible, if I can't afford p1-1 
                             set p1 0 ; nothing left for p1 
                            ]
                            [; if I can't even cover minimum-p3 
                             set p3 profit ;p3 as high as possible
                             set private-wealth private-wealth + profit
                             set p1 0
                             set p2 0
                            ] 
                       ]
                 ]  
           ]
      
     ]
     [; profit has decreased from this period to the next
       ifelse p1-1 >= p1-2 ;the amount given back to investors has increased leading up to this worse result --> increase p2
            [ifelse profit >= p2-1 + adaptation-speed + minimum-p3
                 [ set p3 minimum-p3
                   set private-wealth private-wealth + minimum-p3
                   set p2 p2-1 + adaptation-speed
                   set p1 profit - minimum-p3 - p2
                 ]                 
                 [; can profit at least cover the old p2 + minimum addition to private wealth?
                   ifelse profit >= p2-1 + minimum-p3
                       [set p3 minimum-p3
                        set private-wealth private-wealth + minimum-p3
                        set p2 profit - minimum-p3 ;p2 as high as possible, if I can't afford p2-1 + adaptation-speed 
                        set p1 0 ;nothing left for p1
                       ]
                       [; can profit at least cover the minimum addition to private wealth?
                        ifelse profit >= minimum-p3
                            [set p3 minimum-p3
                             set private-wealth private-wealth + minimum-p3
                             set p2 profit - minimum-p3 ; p1 as high as possible, if I cannot afford p1-1 
                             set p1 0 ; nothing left for p1
                            ]
                            [;if I can't even afford minimum-p3
                             set p3 profit ;p3 as high as possible
                             set private-wealth private-wealth + profit
                             set p1 0
                             set p2 0
                            ] 
                       ]
                 ]  
            ]
            [; the amount given back to investors had decreased, leading to this worse result --> increase it again
             ;increase p1 
             ifelse profit >= p1-1 + adaptation-speed + minimum-p3
                 [ set p3 minimum-p3
                   set private-wealth private-wealth + minimum-p3
                   set p1 p1-1 + adaptation-speed
                   set p2 profit - minimum-p3 - p1
                 ]                 
                 [; can profit at least cover the old p1 + minimum addition to private wealth?
                   ifelse profit >= p1-1 + minimum-p3
                       [set p3 minimum-p3
                        set private-wealth private-wealth + minimum-p3
                        set p1 profit - minimum-p3 ;p1 as high as possible
                        set p2 0 ;nothing left for p2
                       ]
                       [; can profit at least cover the minimum addition to private wealth?
                        ifelse profit >= minimum-p3
                            [set p3 minimum-p3
                             set private-wealth private-wealth + minimum-p3
                             set p1 profit - minimum-p3 ; p1 as high as possible
                             set p2 0 ; nothing left for p2 
                            ]
                            [; if I can't even afford minimum p-3
                             set p3 profit ;p3 as high as possible
                             set private-wealth private-wealth + profit
                             set p1 0
                             set p2 0
                            ] 
                       ]
                 ]  
           
           ] 
     ]
 ]
 ] 
 [;profit < 0 ;  
  set p3 0
  set p1 0
  set p2 0
 ] 

set capital p2    
end




to inform-investors ;entrepreneurs inform investors about their decision

ifelse investment-received > 0 ;if there are investors at all
         [ifelse profit >= 0
               [
                ask my-entrepreneur-links 
                       [set return-received-now amount-invested + ( amount-invested / [investment-received] of myself) * [p1] of myself ;every investor receives what he has given me, plus as an interest rate the proportion of the total investment that I got that came from him times the p1 I have decided on
                        set return-received fput return-received-now return-received ;add new value to return-received list
                        
                        let what-investor-gets return-received-now
                        ask other-end ;the investor adds what I have given him to his capital
                             [set capital capital + what-investor-gets]
                        if amount-invested > 0 [set comparison-list fput (return-received-now / amount-invested) comparison-list] ;what I have just returned is added to a list that the investor will later use to decide if he is disappointed 
                        if length comparison-list > 10 [set comparison-list but-last comparison-list] ;the investors only keep track of the last 10 periods                      
                       ]
               ]
               [; profit negative: the entrepreneurs can't pay off his debt with the investor
                ifelse return + private-wealth >= investment-received ;can the entrepreneur pay off his debt out of private wealth?
                       [; yes
                        ask my-entrepreneur-links 
                           [set return-received-now amount-invested ;no interest rate is paid, just the investment is returned
                            set return-received fput return-received-now return-received ;add the returned amount to the list    
                            let what-investor-gets return-received-now
                            ask other-end 
                                [set capital capital + what-investor-gets] ;the investor adds what I have given him to his capital
                            if amount-invested > 0 [set comparison-list fput (return-received-now / amount-invested) comparison-list]
                            if length comparison-list > 10 [set comparison-list but-last comparison-list]                      
                           ]
                        set private-wealth private-wealth - (investment-received - return) ;entrepreneurs pay the investors out of their private wealth  
                       ]
                       [;no; private wealth is not enough to pay back investors
                        ask my-entrepreneur-links 
                           [set return-received-now (amount-invested / [investment-received] of myself) * ([return] of myself + [private-wealth] of myself) ;every investor receives the proportion of the return payment that corresponds to the proportion of the entrepreneur's total investement that came from this investor 
                            if return-received-now < 0 [set return-received-now 0] ;only relevant for extreme cases when return < 0
                            set return-received fput return-received-now return-received ;add new value to return-received list    
                            let what-investor-gets return-received-now
                            ask other-end 
                                [set capital capital + what-investor-gets]
                           if amount-invested > 0 [set comparison-list fput (return-received-now / amount-invested) comparison-list]
                           if length comparison-list > 10 [set comparison-list but-last comparison-list] 
                           ]
                       set private-wealth 0 ;entrepreneur has lost all his private wealth, that means he must give up and exit the market
                       set should-die 1 ;bankrupt
                       ask my-entrepreneur-links 
                              [let linklength link-length
                              ask other-end [set time-budget-entrepreneurs time-budget-entrepreneurs + linklength] ;link asks the investor to increase its time budget so it can look for new entrepreneurs in the next round
                              set should-die-link 1
                                 
                              ]
  
                              set link-being-cut link-being-cut + 1 ;measures the number of links being cut
                       
                       
                       ]
                 ]
         ]
         [;no investment received this period
          ifelse profit > 0 
                    [
                    ]
                    [;profit < 0 und nichts von Investoren bekommen. Achtung: hier heit das automatisch: return < 0!
                      set private-wealth private-wealth + profit ;profit is negative! 
                      if private-wealth < 0 [
                                             set should-die 1
                                             ask my-entrepreneur-links 
                                                     [let linklength link-length
                                                      ask other-end [set time-budget-entrepreneurs time-budget-entrepreneurs + linklength] ;link asks the investor to increase its time budget so it can look for new entrepreneurs in the next round
                                                      set should-die-link 1
                                                      ]
  
                                                      set link-being-cut link-being-cut + 1
                                             
                                             ] ;bankrupt
                    ]
         
         ]


end


to update-trust
;If the return he or she received is at least disappointment threshold * average return of the other investors in the investors network in the last "memory" periods the investor is satisfied. 

;global list comparisonlist-global

while [any? my-entrepreneur-links with [already-checked1 = 0 and amount-invested > 0]] ;go through all entrepreneur-links to check whether the investor is disappointed or not
   [let ersterkandidat one-of my-entrepreneur-links with [already-checked1 = 0 and amount-invested > 0] ;choose the first entrepreneur-link
    ask ersterkandidat [set being-checked 1];mark him as being checked right now
    if any? investor-link-neighbors 
    [ask investor-link-neighbors ;the investor asks the investors he is connected to
           [ ask my-entrepreneur-links with [already-checked2 = 0] ;the other investors ask their respective links to check their comparison-lists
                [ 
                  foreach comparison-list [set comparisonlist-global fput ? comparisonlist-global]  ;write all entries of the comparison-list to a global list
       
                   set already-checked2 1
                ]
            ]
    ]
     ask my-entrepreneur-links with [being-checked = 0]  ; also use comparison values from my own links and add them to the global list     
            [foreach comparison-list [set comparisonlist-global fput ? comparisonlist-global]  
            ]                 
     if comparisonlist-global = [] [set comparisonlist-global fput 0 comparisonlist-global] ;just to make sure a value can be calculated below
     ifelse [return-received-now / amount-invested] of ersterkandidat >= disappointment-threshold * mean comparisonlist-global ;comparison of average of global list with the current entrepreneur's return
            [ask ersterkandidat [set disappointed 0]]
            [ask ersterkandidat [set disappointed 1]]
     
     
     ask ersterkandidat [set already-checked1 1 ;don't check the same entrepreneur twice
                         set being-checked 0
                         ]
   
   ]
   
   
      
set comparisonlist-global []  ;empty global list for the next investor 
ask entrepreneur-links [set already-checked2 0
                        set already-checked1 0
                        ]

ask my-entrepreneur-links ;this is the actual trust update
   [ifelse disappointed = 1
       [;if disappointed
        set trust trust - trust-decrease
       ]
       [;if not disappointed, and if something was invested
        ifelse amount-invested > 0
        [set trust trust + trust-increase]
        []; otherwise, don't change trust
       ]
   ]




end

to cut-link
ask my-entrepreneur-links
   [ifelse trust < trust-cutoff
     [ifelse should-die-link = 0
       [let linklength link-length
      
        ask myself [set time-budget-entrepreneurs time-budget-entrepreneurs + linklength] ;link asks the investor to increase its time budget so it can look for new entrepreneurs in the next round

        set link-being-cut link-being-cut + 1
        set should-die-link 1 ;link is killed at the beginning of the next period
       ]
       [
       ]
     ]
     [
     ]
   ]

end



to exit
ifelse private-wealth + capital >= saving-target or (inactivity2 - inactivity1 = 10 and inactivity3 = 10); voluntary exit
  [set voluntary 1
   set should-die 1
   
   ask my-entrepreneur-links [ifelse should-die-link = 0
     
                                  [
                                  let linklength link-length
                                  ask other-end [set time-budget-entrepreneurs time-budget-entrepreneurs + linklength] ;link asks the investor to increase its time budget so it can look for new entrepreneurs in the next round
                                  
                                  set link-being-cut link-being-cut + 1
                                  set should-die-link 1
                                  ]
                                  [
                                  ]
                              ]
  
     
   
  ]
  [
  ]
end

to exit-investors
if capital <= 0 or (inactivity2 - inactivity1 = 10 and inactivity3 = 10) ;if investor is bankrupt or inactive
                [
                 
                 set should-die 1
                 ask my-entrepreneur-links 
                                  [ifelse should-die-link = 0
                                     [set link-being-cut link-being-cut + 1
                                     ]
                                     [
                                     ]
                                  ]
  
                   
                 
                 
                 set dead-investors dead-investors + 1
                 set investor-profit-list fput (capital - 1000 ) investor-profit-list
                 ]
end



to do-plots
set-current-plot "number-links"
set-current-plot-pen "investors-to-entrepreneurs"
plot count entrepreneur-links / count investors
set-current-plot "number-links"
set-current-plot-pen "entrepreneurs-to-investors"
plot count entrepreneur-links / count entrepreneurs



set-current-plot "link-being-cut"
plot link-being-cut


set-current-plot "wealth-investors"
plot sum [capital] of investors 

set-current-plot "return-received-now"
plot sum [return-received-now] of entrepreneur-links



set-current-plot "private-wealth-entrepreneurs"
plot sum [private-wealth] of entrepreneurs

set-current-plot "p1-p2-p3"
set-current-plot-pen "p1"
plot mean [p1] of entrepreneurs
set-current-plot-pen "p2"
plot mean [p2] of entrepreneurs
set-current-plot-pen "p3"
plot mean [p3] of entrepreneurs

set-current-plot "voluntary-exits"
set-current-plot-pen "deaths"
plot count entrepreneurs with [should-die = 1]
set-current-plot-pen "voluntary"
plot count entrepreneurs with [voluntary = 1]

set-current-plot "trust"
plot sum [trust] of entrepreneur-links

set-current-plot "age"
plot mean [age] of entrepreneurs

set-current-plot "trustperlink"
if count entrepreneur-links > 0 [plot sum [trust] of entrepreneur-links / count entrepreneur-links]


set-current-plot "histogram-trust"
histogram [trust] of entrepreneur-links

set-current-plot "histogram-return"
histogram return-received-total

end
























@#$#@#$#@
GRAPHICS-WINDOW
290
31
1230
992
15
15
30.0
1
10
1
1
1
0
0
0
1
-15
15
-15
15
0
0
1
ticks

BUTTON
11
16
66
49
NIL
setup\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
7
63
70
96
NIL
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
98
62
163
100
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
2
105
174
138
number-investors
number-investors
0
465
210
1
1
NIL
HORIZONTAL

SLIDER
-2
137
181
170
number-entrepreneurs
number-entrepreneurs
0
465
160
1
1
NIL
HORIZONTAL

SLIDER
0
172
172
205
productivity
productivity
1
3
1.6
0.1
1
NIL
HORIZONTAL

SLIDER
1
206
173
239
trust-cutoff
trust-cutoff
0
1
0.2
0.1
1
NIL
HORIZONTAL

SLIDER
-1
240
189
273
disappointment-threshold
disappointment-threshold
0
1
0.6
0.01
1
NIL
HORIZONTAL

SLIDER
13
274
185
307
memory
memory
0
30
10
1
1
NIL
HORIZONTAL

SLIDER
6
308
190
341
time-constraint-investors
time-constraint-investors
0
30
10
1
1
NIL
HORIZONTAL

SLIDER
6
343
223
376
time-constraint-entrepreneurs
time-constraint-entrepreneurs
0
30
10
1
1
NIL
HORIZONTAL

SLIDER
25
376
197
409
trust-increase
trust-increase
0
1.5
0.5
0.1
1
NIL
HORIZONTAL

SLIDER
29
409
201
442
trust-decrease
trust-decrease
0
3
1.7
0.1
1
NIL
HORIZONTAL

PLOT
1487
72
1647
222
number-links
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -13345367 true
"investors-to-entrepreneurs" 1.0 0 -13345367 true
"entrepreneurs-to-investors" 1.0 0 -955883 true

MONITOR
1273
225
1583
270
mean number of links from investors to entrepreneurs
count entrepreneur-links / count investors
17
1
11

MONITOR
1279
271
1589
316
mean number of links from entrepreneurs to investors
count entrepreneur-links / count entrepreneurs
17
1
11

PLOT
1249
790
1449
940
wealth-investors
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
1274
72
1474
222
return-received-now
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

MONITOR
1214
10
1495
55
NIL
sum [return-received-now] of entrepreneur-links
17
1
11

PLOT
1451
632
1651
782
link-being-cut
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
1449
480
1649
629
private-wealth-entrepreneurs
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
1446
320
1646
472
p1-p2-p3
NIL
NIL
0.0
10.0
0.0
2.0
true
false
PENS
"p1" 1.0 0 -10899396 true
"p2" 1.0 0 -13345367 true
"p3" 1.0 0 -955883 true

SLIDER
23
445
195
478
minimum-p3
minimum-p3
2
10
6
1
1
NIL
HORIZONTAL

SLIDER
21
482
193
515
adaptation-speed
adaptation-speed
1
10
5
1
1
NIL
HORIZONTAL

SLIDER
28
514
200
547
saving-target
saving-target
100
10000
597
1
1
NIL
HORIZONTAL

PLOT
1
843
200
1011
voluntary-exits
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"deaths" 1.0 0 -16777216 true
"voluntary" 1.0 0 -10899396 true

PLOT
1238
327
1438
477
trust
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
0
683
197
833
age
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
1245
477
1445
624
trustperlink
NIL
NIL
0.0
10.0
-1.0
5.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
1456
836
1656
986
histogram-trust
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 1 -10899396 true

SLIDER
23
547
195
580
investment
investment
10
100
70
1
1
NIL
HORIZONTAL

SLIDER
15
583
187
616
mean-stochastic
mean-stochastic
-1
1
0
0.01
1
NIL
HORIZONTAL

SLIDER
21
633
193
666
variance-stochastic
variance-stochastic
0
2
0.8
0.01
1
NIL
HORIZONTAL

MONITOR
1452
786
1656
831
NIL
mean link-age-at-death 
17
1
11

PLOT
1247
630
1447
780
histogram-return
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 1 -16777216 true

MONITOR
1509
10
1643
55
New links per investor
count entrepreneur-links with [new-link = 1] / count investors
17
1
11

MONITOR
1273
943
1398
988
NIL
duration-investment\n
17
1
11

@#$#@#$#@
WHAT IS IT?
-----------
This section could give a general understanding of what the model is trying to show or explain.


HOW IT WORKS
------------
This section could explain what rules the agents use to create the overall behavior of the model.


HOW TO USE IT
-------------
This section could explain how to use the model, including a description of each of the items in the interface tab.


THINGS TO NOTICE
----------------
This section could give some ideas of things for the user to notice while running the model.


THINGS TO TRY
-------------
This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.


EXTENDING THE MODEL
-------------------
This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.


NETLOGO FEATURES
----------------
This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.


RELATED MODELS
--------------
This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.


CREDITS AND REFERENCES
----------------------
This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

computer workstation
false
0
Rectangle -7500403 true true 60 45 240 180
Polygon -7500403 true true 90 180 105 195 135 195 135 210 165 210 165 195 195 195 210 180
Rectangle -16777216 true false 75 60 225 165
Rectangle -7500403 true true 45 210 255 255
Rectangle -10899396 true false 249 223 237 217
Line -16777216 false 60 225 120 225

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dollar bill
false
0
Rectangle -7500403 true true 15 90 285 210
Rectangle -1 true false 30 105 270 195
Circle -7500403 true true 120 120 60
Circle -7500403 true true 120 135 60
Circle -7500403 true true 254 178 26
Circle -7500403 true true 248 98 26
Circle -7500403 true true 18 97 36
Circle -7500403 true true 21 178 26
Circle -7500403 true true 66 135 28
Circle -1 true false 72 141 16
Circle -7500403 true true 201 138 32
Circle -1 true false 209 146 16
Rectangle -16777216 true false 64 112 86 118
Rectangle -16777216 true false 90 112 124 118
Rectangle -16777216 true false 128 112 188 118
Rectangle -16777216 true false 191 112 237 118
Rectangle -1 true false 106 199 128 205
Rectangle -1 true false 90 96 209 98
Rectangle -7500403 true true 60 168 103 176
Rectangle -7500403 true true 199 127 230 133
Line -7500403 true 59 184 104 184
Line -7500403 true 241 189 196 189
Line -7500403 true 59 189 104 189
Line -16777216 false 116 124 71 124
Polygon -1 true false 127 179 142 167 142 160 130 150 126 148 142 132 158 132 173 152 167 156 164 167 174 176 161 193 135 192
Rectangle -1 true false 134 199 184 205

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="skalierung_v14" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>count entrepreneur-links / count investors</metric>
    <metric>sum [wealth] of investors</metric>
    <metric>sum [return-received-now] of entrepreneur-links / count investors</metric>
    <metric>sum [amount-invested] of entrepreneur-links / count investors</metric>
    <metric>sum [trust] of entrepreneur-links / count investors</metric>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
      <value value="30"/>
      <value value="50"/>
      <value value="80"/>
      <value value="100"/>
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-investors">
      <value value="5"/>
      <value value="10"/>
      <value value="30"/>
      <value value="50"/>
      <value value="80"/>
      <value value="100"/>
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="invested-amount">
      <value value="10"/>
      <value value="20"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exponent-production">
      <value value="0.65"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="voluntary-exit_v12" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [p1 = 0 and p2 = 0 and age &gt; 0]</metric>
    <metric>count entrepreneurs with [investment-received = 0 and age &gt; 0]</metric>
    <metric>count entrepreneurs with [p1 = 0 and p2 = 0 and investment-received = 0 and age &gt; 0]</metric>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="invested-amount">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-investors">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="production" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>mean [age] of entrepreneurs</metric>
    <metric>count entrepreneur-links / count investors</metric>
    <metric>sum [wealth] of investors</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <enumeratedValueSet variable="invested-amount">
      <value value="2"/>
      <value value="5"/>
      <value value="10"/>
      <value value="20"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
      <value value="10"/>
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="trust_v12" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>link-being-cut</metric>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="invested-amount">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-investors">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="trust_skalierung_trustproinvestor_v12" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>sum [trust] of entrepreneur-links / count investors</metric>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
      <value value="30"/>
      <value value="50"/>
      <value value="80"/>
      <value value="100"/>
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-investors">
      <value value="5"/>
      <value value="10"/>
      <value value="30"/>
      <value value="50"/>
      <value value="80"/>
      <value value="100"/>
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="invested-amount">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="trust_variation_v14" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>count entrepreneur-links / count investors</metric>
    <metric>sum [wealth] of investors</metric>
    <metric>sum [return-received-now] of entrepreneur-links / count investors</metric>
    <metric>sum [amount-invested] of entrepreneur-links / count investors</metric>
    <metric>sum [trust] of entrepreneur-links / count investors</metric>
    <enumeratedValueSet variable="invested-amount">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.5"/>
      <value value="1"/>
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.5"/>
      <value value="1"/>
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.8"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-investors">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exponent-production">
      <value value="0.65"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="skalierung_v13_trustperlink" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>sum [age] of entrepreneurs / count entrepreneurs</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="invested-amount">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
      <value value="30"/>
      <value value="50"/>
      <value value="80"/>
      <value value="100"/>
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-investors">
      <value value="5"/>
      <value value="10"/>
      <value value="30"/>
      <value value="50"/>
      <value value="80"/>
      <value value="100"/>
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exponent-production">
      <value value="0.5"/>
      <value value="0.52"/>
      <value value="0.54"/>
      <value value="0.56"/>
      <value value="0.58"/>
      <value value="0.6"/>
      <value value="0.62"/>
      <value value="0.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="production_v14" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>count entrepreneur-links / count investors</metric>
    <metric>sum [wealth] of investors</metric>
    <metric>sum [return-received-now] of entrepreneur-links / count investors</metric>
    <metric>sum [amount-invested] of entrepreneur-links / count investors</metric>
    <metric>sum [trust] of entrepreneur-links / count investors</metric>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-investors">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="invested-amount">
      <value value="2"/>
      <value value="5"/>
      <value value="10"/>
      <value value="20"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
      <value value="10"/>
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exponent-production">
      <value value="0.5"/>
      <value value="0.52"/>
      <value value="0.54"/>
      <value value="0.56"/>
      <value value="0.58"/>
      <value value="0.6"/>
      <value value="0.62"/>
      <value value="0.64"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v14" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>count entrepreneur-links</metric>
    <metric>sum [wealth] of investors</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>count entrepreneurs with [investment-received &gt; 0]</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [p1 = 0 and p2 = 0 and age &gt; 0]</metric>
    <metric>count entrepreneurs with [investment-received = 0 and age &gt; 0]</metric>
    <metric>count entrepreneurs with [p1 = 0 and p2 = 0 and investment-received = 0 and age &gt; 0]</metric>
    <metric>sum [return] of entrepreneurs</metric>
    <metric>sum [wealth] of entrepreneurs</metric>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="invested-amount">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-investors">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="exponent-production">
      <value value="0.65"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v23_teil1" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>mean link-age-at-death</metric>
    <metric>count entrepreneur-links / count entrepreneurs</metric>
    <metric>count entrepreneur-links with [new-link = 1] / count investors</metric>
    <metric>sum return-received-bigger / dead-links</metric>
    <metric>best-percent</metric>
    <metric>return-measure</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <steppedValueSet variable="saving-target" first="200" step="200" last="2800"/>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
      <value value="180"/>
      <value value="200"/>
      <value value="220"/>
      <value value="240"/>
      <value value="260"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.5"/>
      <value value="1.6"/>
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v23_teil2" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>mean link-age-at-death</metric>
    <metric>count entrepreneur-links / count entrepreneurs</metric>
    <metric>count entrepreneur-links with [new-link = 1] / count investors</metric>
    <metric>sum return-received-bigger / dead-links</metric>
    <metric>best-percent</metric>
    <metric>return-measure</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <steppedValueSet variable="saving-target" first="200" step="200" last="2800"/>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
      <value value="180"/>
      <value value="200"/>
      <value value="220"/>
      <value value="240"/>
      <value value="260"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.5"/>
      <value value="1.6"/>
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v23_teil3" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>mean link-age-at-death</metric>
    <metric>count entrepreneur-links / count entrepreneurs</metric>
    <metric>count entrepreneur-links with [new-link = 1] / count investors</metric>
    <metric>sum return-received-bigger / dead-links</metric>
    <metric>best-percent</metric>
    <metric>return-measure</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <steppedValueSet variable="saving-target" first="200" step="200" last="2800"/>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
      <value value="180"/>
      <value value="200"/>
      <value value="220"/>
      <value value="240"/>
      <value value="260"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.5"/>
      <value value="1.6"/>
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v23_cali1" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>mean link-age-at-death</metric>
    <metric>count entrepreneur-links / count entrepreneurs</metric>
    <metric>count entrepreneur-links with [new-link = 1] / count investors</metric>
    <metric>sum return-received-bigger / dead-links</metric>
    <metric>best-percent</metric>
    <metric>return-measure</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="2800"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v23_cali2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>mean link-age-at-death</metric>
    <metric>count entrepreneur-links / count entrepreneurs</metric>
    <metric>count entrepreneur-links with [new-link = 1] / count investors</metric>
    <metric>sum return-received-bigger / dead-links</metric>
    <metric>best-percent</metric>
    <metric>return-measure</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="2.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v23_cali3" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>mean link-age-at-death</metric>
    <metric>count entrepreneur-links / count entrepreneurs</metric>
    <metric>count entrepreneur-links with [new-link = 1] / count investors</metric>
    <metric>sum return-received-bigger / dead-links</metric>
    <metric>best-percent</metric>
    <metric>return-measure</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="-0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="260"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="1.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v23_cali4" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>mean link-age-at-death</metric>
    <metric>count entrepreneur-links / count entrepreneurs</metric>
    <metric>count entrepreneur-links with [new-link = 1] / count investors</metric>
    <metric>sum return-received-bigger / dead-links</metric>
    <metric>best-percent</metric>
    <metric>return-measure</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="2900"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="-1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="280"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v23_baseline" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>mean link-age-at-death</metric>
    <metric>count entrepreneur-links / count entrepreneurs</metric>
    <metric>count entrepreneur-links with [new-link = 1] / count investors</metric>
    <metric>sum return-received-bigger / dead-links</metric>
    <metric>best-percent</metric>
    <metric>return-measure</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_numberinvestors" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="100"/>
      <value value="210"/>
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_numberentrepreneurs" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="100"/>
      <value value="160"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_timeconstraint_investors" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_timeconstraint_entrepreneurs" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_productivity" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1"/>
      <value value="1.6"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_disappointment" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.2"/>
      <value value="0.6"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_adaptation" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_savingtarget" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="100"/>
      <value value="600"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_cutoff" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0"/>
      <value value="0.2"/>
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_p3" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="0"/>
      <value value="6"/>
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_variance" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.2"/>
      <value value="0.8"/>
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_investment" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="10"/>
      <value value="70"/>
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_trustdecrease" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="0.1"/>
      <value value="1.7"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_trustincrease" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part1" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <steppedValueSet variable="disappointment-threshold" first="0.2" step="0.1" last="1"/>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="investment" first="10" step="10" last="150"/>
    <enumeratedValueSet variable="trust-decrease">
      <value value="0.1"/>
      <value value="0.4"/>
      <value value="0.7"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part2" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <steppedValueSet variable="disappointment-threshold" first="0.2" step="0.1" last="1"/>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="investment" first="10" step="10" last="150"/>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.3"/>
      <value value="1.6"/>
      <value value="1.9"/>
      <value value="2.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part3" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <steppedValueSet variable="disappointment-threshold" first="0.2" step="0.1" last="1"/>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="investment" first="10" step="10" last="150"/>
    <enumeratedValueSet variable="trust-decrease">
      <value value="2.5"/>
      <value value="2.8"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part4" repetitions="3" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <steppedValueSet variable="disappointment-threshold" first="0.2" step="0.1" last="1"/>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="investment" first="10" step="10" last="150"/>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part5" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="110"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <steppedValueSet variable="disappointment-threshold" first="0.2" step="0.1" last="1"/>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part6" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="110"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="investment" first="10" step="10" last="150"/>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part7" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="110"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <steppedValueSet variable="trust-decrease" first="0.1" step="0.3" last="3.1"/>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part8" repetitions="300" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <steppedValueSet variable="disappointment-threshold" first="0.2" step="0.1" last="1"/>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="0.1"/>
      <value value="0.4"/>
      <value value="0.7"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part9" repetitions="300" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <steppedValueSet variable="disappointment-threshold" first="0.2" step="0.1" last="1"/>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.3"/>
      <value value="1.6"/>
      <value value="1.7"/>
      <value value="1.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part10" repetitions="300" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <steppedValueSet variable="disappointment-threshold" first="0.2" step="0.1" last="1"/>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="2.2"/>
      <value value="2.5"/>
      <value value="2.8"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part11" repetitions="1000" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="101"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <steppedValueSet variable="disappointment-threshold" first="0.2" step="0.1" last="1"/>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part12" repetitions="1000" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="101"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
      <value value="1.1"/>
      <value value="1.3"/>
      <value value="1.5"/>
      <value value="1.7"/>
      <value value="1.9"/>
      <value value="2.1"/>
      <value value="2.3"/>
      <value value="2.5"/>
      <value value="2.7"/>
      <value value="2.9"/>
      <value value="3.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="v24_optitrust_part16" repetitions="1000" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="101"/>
    <metric>duration-investment</metric>
    <metric>sum [return-received-now] of entrepreneur-links</metric>
    <metric>sum [amount-invested] of entrepreneur-links</metric>
    <metric>sum [trust] of entrepreneur-links</metric>
    <metric>sum [p1] of entrepreneurs</metric>
    <metric>sum [p2] of entrepreneurs</metric>
    <metric>sum [p3] of entrepreneurs</metric>
    <metric>count entrepreneurs with [should-die = 1]</metric>
    <metric>count entrepreneurs with [voluntary = 1]</metric>
    <metric>count entrepreneur-links</metric>
    <enumeratedValueSet variable="number-investors">
      <value value="210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-investors">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="productivity">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="disappointment-threshold">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="memory">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adaptation-speed">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="saving-target">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-cutoff">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-stochastic">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimum-p3">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-entrepreneurs">
      <value value="160"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="variance-stochastic">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-constraint-entrepreneurs">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="investment">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-decrease">
      <value value="1.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trust-increase">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
